cancel method
PubSub uses this method to cancel subscription on it This method not intended to be manual called.
Implementation
Future<void>? cancel() async {
await _controller?.close();
_isCanceled = true;
}
PubSub uses this method to cancel subscription on it This method not intended to be manual called.
Future<void>? cancel() async {
await _controller?.close();
_isCanceled = true;
}