UikAvatarProps class

Inheritance
Annotations

Constructors

UikAvatarProps()
UikAvatarProps.fromJson(Map<String, dynamic> json)
factory

Properties

action UikAction
getter/setter pair
backgroundColor Color
getter/setter pair
backgroundImage String
getter/setter pair
borderRadius double
getter/setter pair
child Widget
getter/setter pair
foregroundColor Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
id String
getter/setter pair
padding double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape
getter/setter pair
size double
getter/setter pair
width double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited