UikImageProps class

Inheritance
Annotations

Constructors

UikImageProps()
UikImageProps.fromJson(Map<String, dynamic> json)
factory

Properties

action UikAction
getter/setter pair
borderColor Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
id String
getter/setter pair
iFit BoxFit
getter/setter pair
opacity ↔ dynamic
getter/setter pair
rad double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String
getter/setter pair
wid double
getter/setter pair
width double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited